# Neat-ml schema

Neat-ml schema defines the schema in the form of a [YAML file](https://github.com/Knowledge-Graph-Hub/neat_ml_schema/blob/main/src/schema/neat_ml_schema.yaml) for data going into graph ML pipelines (specifically [NEAT](https://github.com/Knowledge-Graph-Hub/neat-ml)). This project itself is generated using the command `linkml-ws new` derived from the [linkML](https://github.com/linkml/linkml) project.

[Documentation](https://knowledge-graph-hub.github.io/neat_ml_schema/)
